/** 
 * Program:  Ising.java
 * A simple program to calculate properties of the two-dimensional
 * Ising model using the Monte Carlo method.
 **/

import java.awt.*;
import java.awt.event.*;

public class Ising extends Frame {
  // Define some class variables.
  
  public static final int XDIM=10, YDIM=10;
  public static final int UP=1, DOWN=2, CHECKER=3;

  public static final double J=10.;
  public static final double SPIN_UP=1.0;
  public static final double SPIN_DN=-1.0;

  double spins[][]=new double[XDIM][YDIM];

  // This is a constructor method.
  public Ising(int istart) {
    
    super("2D Ising Model");
    switch(istart){
    case UP:
      for(int i=0;i<XDIM;i++)
	for(int j=0;j<YDIM;j++)	
	  spins[i][j]=SPIN_UP;
      break;

    case DOWN:
      for(int i=0;i<XDIM;i++)
	for(int j=0;j<YDIM;j++)	
	  spins[i][j]=SPIN_DN;
      break;

    case CHECKER:
      double spin_old=SPIN_DN;
      for(int i=0;i<XDIM;i++)
	for(int j=0;j<YDIM;j++)
	  if(spin_old==SPIN_DN){
	    spins[i][j]=SPIN_UP;
	    spin_old=SPIN_UP;
	  }
	  else {
	    spins[i][j]=SPIN_DN;
	    spin_old=SPIN_DN;
	  }
      break;
      
    default:
      System.out.println("Illegal option");
      break;
    }
  }
  
  public void printIt(){
    for(int i=0;i<XDIM;i++)
      for(int j=0;j<YDIM;j++)	
	System.out.println(i+" "+j+" "+spins[i][j]);
  }
  
  public static void main(String[] args) {
    int istart=UP;
    Ising itest=new Ising(istart);
    itest.setSize(500,400);
    itest.addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent e) {System.exit(0);}
    });
    itest.show();
    itest.add(new IsCanvas(itest.spins));
    //itest.add(new IsCanvas());
    //    itest.add(new IsCanvas(itest.XDIM));
  }
}
 
/**
 * Program IsCanvas.java
 * This program plots the spins.  A grid is drawn and spins are
 * labels red for up, green for down.  Very Christmasy.
 * This program can be separated from the main file.  Call it IsCanvas.java
 * and make the class file with javac IsCanvas.java.
 * Also, add "import java.awt.*;" as the first line (drop the quotes).
 **/

class IsCanvas extends Canvas {
  
  //A constructor

  //Another constructor
  public IsCanvas() {;}

  //Still another constructor
  public IsCanvas(int atest){
    this.atest=atest;
  }
    
  // Draw the grid and color in the squares
  public void paint(Graphics g) {
    
    //Size of the window
    int w = getSize().width;
    int h = getSize().height;
    
    //Spacing between lines
    double dw=(double)w/(double)Ising.XDIM;
    double dh=(double)h/(double)Ising.YDIM;
    
    //Fill in the squares
    g.setColor(Color.red);
    for(int i=0;i<Ising.XDIM;i++)
      for(int j=0;j<Ising.YDIM;j++)
	if(spins[i][j]==1) {
	  g.fillRect(i*(int)dw,j*(int)dh,(i+1)*(int)dw,(j+1)*(int)dh);
	}

    //Draw the grid
    for(int i=0;i<Ising.XDIM;i++)
      g.drawLine(i*(int)dw,0,i*(int)dw,h);
    for(int i=0;i<Ising.YDIM;i++)
      g.drawLine(0,i*(int)dh,w,i*(int)dh);

  }
  
  //If we don't specify this, the canvas might not show up at all
  //(depending on the layout manager).
  public Dimension getMinimumSize() {
    return new Dimension(150,130);
  }
  
  //If we don't specify this, the canvas might not show up at all
  //(depending on the layout manager).
  public Dimension getPreferredSize() {
    return getMinimumSize();
  }
}
 
    


